@@ -17,7 +17,6 @@ from numpy import linalg as LA
 
 from AMAT.planet import Planet
 
-solar_system_ephemeris.set('../spice-data/de432s.bsp')
 
 class Arrival:
 	"""
@@ -50,6 +49,7 @@ class Arrival:
 		self.angle = None
 		self.declination = None
 
+
 	def set_vinf_vec_manually(self, arrivalPlanet, v_inf_vec_ICRF_kms):
 		"""
 		Set arrival v_inf_vec manually if available
@@ -83,7 +83,7 @@ class Arrival:
 		self.declination = 90 - self.angle
 
 	def set_vinf_vec_from_lambert_arc(self, lastFlybyPlanet, arrivalPlanet, lastFlybyDate, arrivalDate,
-									  M=0, numiter=100, rtol=1e-6):
+									  M=0, numiter=100, rtol=1e-6, ephem_file='../spice-data/de432s.bsp'):
 		"""
 		Compute the v_inf_vec from a lambert arc solution
 		if the last flyby date and the arrival date is known
@@ -115,10 +115,13 @@ class Arrival:
 		rtol: float, optional
 			relative tolerance for lambert solver
 			defaults to 1e-6
+		ephem_file : str
+			ephemeris filepath to spice-data/de432.bsp
 		"""
 
-		self.lastFlybyPlanet_eph = get_body_barycentric_posvel(lastFlybyPlanet, lastFlybyDate)
-		self.arrivalPlanet_eph = get_body_barycentric_posvel(arrivalPlanet, arrivalDate)
+		with solar_system_ephemeris.set(ephem_file):
+			self.lastFlybyPlanet_eph = get_body_barycentric_posvel(lastFlybyPlanet, lastFlybyDate)
+			self.arrivalPlanet_eph = get_body_barycentric_posvel(arrivalPlanet, arrivalDate)
 
 		self.TOF = arrivalDate - lastFlybyDate
 
@@ -138,10 +141,10 @@ class Arrival:
 										   self.arrivalPlanet_eph[1].y.value / 86400,
 										   self.arrivalPlanet_eph[1].z.value / 86400])
 
-		(self.v_dep, self.v_arr), = iod.izzo.lambert(Sun.k, self.lastFlybyPlanet_pos * u.km,
-													 self.arrivalPlanet_pos * u.km,
-													 self.TOF,
-													 M=M, numiter=numiter, rtol=rtol)
+		(self.v_dep, self.v_arr) = iod.izzo.lambert(Sun.k, self.lastFlybyPlanet_pos * u.km,
+												    self.arrivalPlanet_pos * u.km,
+													self.TOF,
+													M=M, numiter=numiter, rtol=rtol)
 
 		self.v_inf_vec = self.v_arr.value - self.arrivalPlanet_vel
 		self.v_inf_mag = LA.norm(self.v_inf_vec)
